import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DisableMetricsCollectionQuery } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DisableMetricsCollectionCommand}.
 */
export interface DisableMetricsCollectionCommandInput extends DisableMetricsCollectionQuery {
}
/**
 * @public
 *
 * The output of {@link DisableMetricsCollectionCommand}.
 */
export interface DisableMetricsCollectionCommandOutput extends __MetadataBearer {
}
declare const DisableMetricsCollectionCommand_base: {
    new (input: DisableMetricsCollectionCommandInput): import("@smithy/smithy-client").CommandImpl<DisableMetricsCollectionCommandInput, DisableMetricsCollectionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DisableMetricsCollectionCommandInput): import("@smithy/smithy-client").CommandImpl<DisableMetricsCollectionCommandInput, DisableMetricsCollectionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Disables group metrics collection for the specified Auto Scaling group.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DisableMetricsCollectionCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DisableMetricsCollectionCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // DisableMetricsCollectionQuery
 *   AutoScalingGroupName: "STRING_VALUE", // required
 *   Metrics: [ // Metrics
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new DisableMetricsCollectionCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DisableMetricsCollectionCommandInput - {@link DisableMetricsCollectionCommandInput}
 * @returns {@link DisableMetricsCollectionCommandOutput}
 * @see {@link DisableMetricsCollectionCommandInput} for command's `input` shape.
 * @see {@link DisableMetricsCollectionCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To disable metrics collection for an Auto Scaling group
 * ```javascript
 * // This example disables collecting data for the GroupDesiredCapacity metric for the specified Auto Scaling group.
 * const input = {
 *   "AutoScalingGroupName": "my-auto-scaling-group",
 *   "Metrics": [
 *     "GroupDesiredCapacity"
 *   ]
 * };
 * const command = new DisableMetricsCollectionCommand(input);
 * await client.send(command);
 * // example id: autoscaling-disable-metrics-collection-1
 * ```
 *
 */
export declare class DisableMetricsCollectionCommand extends DisableMetricsCollectionCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DisableMetricsCollectionQuery;
            output: {};
        };
        sdk: {
            input: DisableMetricsCollectionCommandInput;
            output: DisableMetricsCollectionCommandOutput;
        };
    };
}
